@@ -19,6 +19,7 @@ from .exceptions import (
 )
 from .job import get_job_variable
 from .runner import PaasRunner
+from .util import retry
 
 logger = logging.getLogger(__name__)
 
@@ -29,6 +30,8 @@ DEFAULT_FLAVOR = 'M'
 CC_ORGA_ID_ATTRIBUTE = 'cc_orga_id'
 CC_ORGA_TOKEN_ATTRIBUTE = 'cc_orga_token'
 
+CC_API_RETRY_DELAY_SECONDS = 2
+
 
 def convert_http_error(http_response):
     """Return error code, message."""
@@ -90,6 +93,7 @@ class CleverCloudDockerRunner(PaasRunner):
                                        )
 
     @property
+    @retry(attempts=3, delay_seconds=CC_API_RETRY_DELAY_SECONDS)
     def available_flavors(self):
         """Cached dict of available flavors.
 
@@ -173,6 +177,7 @@ class CleverCloudDockerRunner(PaasRunner):
         return (key != 'heptapod_runner_main_image'
                 and not key.startswith('cc_'))
 
+    @retry(attempts=3, delay_seconds=CC_API_RETRY_DELAY_SECONDS)
     def cc_docker_instance_type(self):
         """Retrieve the CC instance type that we'll be using, with details.
 
@@ -380,7 +385,7 @@ class CleverCloudDockerRunner(PaasRunner):
                                                                 self.config)
             build_helper.write_build_context(self, job_data)
             try:
-                build_helper.git_push(paas_resource.git_push_url)
+                out_err = build_helper.git_push(paas_resource.git_push_url)
             except DeploymentBranchAlreadyExisting:
                 logger.warning(
                     "%s: depoyment branch already existing on remote. "
@@ -388,6 +393,12 @@ class CleverCloudDockerRunner(PaasRunner):
                     "or shutdown (SIGKILL or bug in shutdown sequence)",
                     paas_resource.log_fmt()
                 )
+            else:
+                logger.debug('%s: deployment by Git push to %r done. '
+                             'git subprocess stdout/stderr: %r',
+                             paas_resource.log_fmt(),
+                             paas_resource.deploy_url,
+                             out_err)
 
         paas_resource.launched = True
 
