@@ -11,6 +11,7 @@ import re
 import subprocess
 
 from .exceptions import DeploymentBranchAlreadyExisting
+from .util import retry
 from .version import version_str
 
 from .job import (
@@ -246,6 +247,15 @@ class DockerBuildHelper:
         self.git('remote', 'add', remote, url)
         # TODO expected remote branch could become, e.g, 'main'
         remote_branch = 'master'
+        self.git_inner_push(url, remote, remote_branch)
+
+    @retry(attempts=3, delay_seconds=2,
+           break_exceptions=(DeploymentBranchAlreadyExisting, ))
+    def git_inner_push(self, url, remote, remote_branch):
+        """Singled out interaction with remote for retry logic.
+
+        :param url: used in error raising only
+        """
         if self.git('ls-remote', remote, remote_branch):
             raise DeploymentBranchAlreadyExisting(url, remote_branch)
         return self.git('push', '-q', '--set-upstream', remote, remote_branch,
