@@ -714,6 +714,25 @@ class PaasDispatcher:
             # runner) to handle that, but that will be good enough for now.
             # Also, waiting times should be per coordinator
 
+            headroom = self.weighted_quota - self.potential_weight
+            if headroom <= 0 or self.max_pending_jobs_reached():
+                can_take_job = False
+            else:
+                can_take_job = headroom > min(
+                    runner.min_requestable_weight
+                    for runner in self.runners.values())
+
+            logger.info("JSON statistics: %s", json.dumps(dict(
+                weight_quota=self.weighted_quota,
+                current_weight=self.potential_weight,
+                weight_headroom=headroom,
+                can_take_job=can_take_job,
+                max_jobs_in_provisioning=self.max_pending_jobs,
+                jobs_in_provisioning=len(self.pending_jobs),
+                current_concurrent_jobs=self.potential_concurrency,
+                max_concurrent_jobs=self.max_concurrency,
+                )))
+
             if (
                     self.potential_concurrency >= self.max_concurrency
                     or self.potential_weight >= self.weighted_quota
